==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionCatalogHealthFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCatalogSourceRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getCatalogSourceRef();
  public io.fabric8.kubernetes.api.model.ObjectReference buildCatalogSourceRef();
  public A withCatalogSourceRef(io.fabric8.kubernetes.api.model.ObjectReference catalogSourceRef);
  public java.lang.Boolean hasCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.Boolean getHealthy();
  public A withHealthy(java.lang.Boolean healthy);
  public java.lang.Boolean hasHealthy();
  public java.lang.String getLastUpdated();
  public A withLastUpdated(java.lang.String lastUpdated);
  public java.lang.Boolean hasLastUpdated();
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0);
  public interface CatalogSourceRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>>{
    public N and();
    public N endCatalogSourceRef();
    
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionCatalogHealthFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SubscriptionCatalogHealthFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCatalogSourceRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getCatalogSourceRef();
  public io.fabric8.kubernetes.api.model.ObjectReference buildCatalogSourceRef();
  public A withCatalogSourceRef(io.fabric8.kubernetes.api.model.ObjectReference catalogSourceRef);
  public java.lang.Boolean hasCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> withNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRef();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<A> editOrNewCatalogSourceRefLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.Boolean getHealthy();
  public A withHealthy(java.lang.Boolean healthy);
  public java.lang.Boolean hasHealthy();
  public java.lang.String getLastUpdated();
  public A withLastUpdated(java.lang.String lastUpdated);
  public java.lang.Boolean hasLastUpdated();
  
  /**
   * Method is deprecated. use withLastUpdated instead.
   */
  @java.lang.Deprecated
  public A withNewLastUpdated(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CatalogSourceRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionCatalogHealthFluent.CatalogSourceRefNested<N>>{
    public N and();
    public N endCatalogSourceRef();
    
  }
  
}
